@@ -1,14 +1,14 @@
 from __future__ import print_function, division
 import time
-from .delay_import import import_
-from .arrays import ensure_type, cast_indices
-from .unit import in_units_of, convert
-from .unitcell import (lengths_and_angles_to_box_vectors,
+from mdtraj.utils.delay_import import import_
+from mdtraj.utils.arrays import ensure_type, cast_indices
+from mdtraj.utils.unit import in_units_of
+from mdtraj.utils.unitcell import (lengths_and_angles_to_box_vectors,
                        box_vectors_to_lengths_and_angles)
 
 __all__ = ["ensure_type", "import_", "in_units_of",
     "lengths_and_angles_to_box_vectors", "box_vectors_to_lengths_and_angles",
-    "ilen", "timing", "cast_indices", "convert"]
+    "ilen", "timing", "cast_indices"]
 
 
 def ilen(iterable):
